@@ -1,4 +1,4 @@
-#$Id: Neo4p.pm 17638 2012-08-30 03:52:17Z jensenma $
+#$Id: Neo4p.pm 17640 2012-08-30 13:46:38Z jensenma $
 package REST::Neo4p;
 use strict;
 use warnings;
@@ -12,10 +12,13 @@ use REST::Neo4p::Query;
 use REST::Neo4p::Exceptions;
 
 BEGIN {
-  $REST::Neo4p::VERSION = '0.1';
+  $REST::Neo4p::VERSION = '0.12';
 }
+
+our $CREATE_AUTO_ACCESSORS = 0;
 our $AGENT;
 
+
 # connect($host_and_port)
 sub connect {
   my $class = shift;
@@ -30,20 +33,20 @@ sub connect {
 sub get_node_by_id {
   my $class = shift;
   my ($id) = @_;
-  return REST::Neo4p::Entity->_entity_by_id('node',$id);
+  return REST::Neo4p::Node->_entity_by_id($id);
 }
 
 # $reln = REST::Neo4p->get_relationship_by_id($id);
 sub get_relationship_by_id {
   my $class = shift;
   my ($id) = @_;
-  return REST::Neo4p::Entity->_entity_by_id('relationship',$id);
+  return REST::Neo4p::Relationship->_entity_by_id($id);
 }
 
 sub get_index_by_name {
   my $class = shift;
   my ($name) = @_;
-  return REST::Neo4p::Entity->_entity_by_id('index',$name);
+  return REST::Neo4p::Index->_entity_by_id($name);
 }
 
 # @all_reln_types = REST::Neo4p->get_relationship_types
@@ -114,6 +117,31 @@ Actions on class instances have a corresponding effect on the database
 
 The class L<REST::Neo4p::Query> provides a DBIesqe Cypher query facility.
 
+=head2 Property Auto-accessors
+
+Depending on the application, it may be natural to think of properties
+as fields of your nodes and relationships. To create accessors named
+for the entity properties, set
+
+ $REST::Neo4p::CREATE_AUTO_ACCESSORS = 1;
+
+Then, when L</set_property()> is used to first create and set a
+property, accessors will be created on the class:
+
+ $node1->set_property({ flavor => 'strange', spin => -0.5 });
+ printf "Quark has flavor %s\n", $node1->flavor;
+ $node1->set_spin(0.5);
+
+If your point of reference is the database, rather than the objects,
+auto-accessors may be confusing, since once the accessor is created
+for the class, it will exist for all future instances:
+
+ print "Yes I can!\n" if REST::Neo4p::Node->new()->can('flavor');
+
+but there is no fundamental reason why new nodes or relationships must
+have the property (it is NoSQL, after all). Therefore this is a choice
+for you to make; the default is I<no> auto-accessors.
+
 =head1 CLASS METHODS
 
 =over
@@ -155,6 +183,10 @@ The class L<REST::Neo4p::Query> provides a DBIesqe Cypher query facility.
 
 =head1 LICENSE
 
+Copyright (c) 2012 Mark A. Jensen. This program is free software; you
+can redistribute it and/or modify it under the same terms as Perl
+itself.
+
 =cut
 
 1;
